pub enum Body {
Unstructured(ExprBody),
Structured(ExprBody),
TargetDispatch(SeqHashMap<TargetTriple, FunDeclRef>),
TraitMethodWithoutDefault,
Extern(String),
Intrinsic {
name: String,
arg_names: Vec<Option<String>>,
},
Opaque,
Missing,
Error(Error),
}Expand description
The body of a function.
Variants
Unstructured(ExprBody)
Body represented as a CFG. This is what ullbc is made of, and what we get after translating MIR.
Structured(ExprBody)
Body represented with structured control flow. This is what llbc is made of. We restructure
the control flow in the ullbc_to_llbc pass.
TargetDispatch(SeqHashMap<TargetTriple, FunDeclRef>)
A façade body that dispatches to one of several per-target function bodies. Created during multi-target merging for functions with the same signature but different bodies across targets.
TraitMethodWithoutDefault
The body of the function item we add for each trait method declaration, if the trait doesn’t provide a default for that method.
Extern(String)
Function declared in an extern { ... } block. The string is the foreign symbol name.
Intrinsic
Rust intrinsic function.
Fields
Opaque
A body that the user chose not to translate, based on opacity settings like
--include/--opaque.
Missing
A body that was not available. Typically that’s function bodies for non-generic and
non-inlineable std functions, as these are not present in the compiled standard library
.rmeta file shipped with a rust toolchain.
Error(Error)
We encountered an error while translating this body.
Implementations
Sourceimpl Body
impl Body
pub fn is_unstructured(&self) -> bool
pub fn is_structured(&self) -> bool
pub fn is_target_dispatch(&self) -> bool
pub fn is_trait_method_without_default(&self) -> bool
pub fn is_extern(&self) -> bool
pub fn is_intrinsic(&self) -> bool
pub fn is_opaque(&self) -> bool
pub fn is_missing(&self) -> bool
pub fn is_error(&self) -> bool
Sourceimpl Body
impl Body
pub fn as_unstructured(&self) -> Option<&ExprBody>
pub fn as_structured(&self) -> Option<&ExprBody>
pub fn as_target_dispatch( &self, ) -> Option<&SeqHashMap<TargetTriple, FunDeclRef>>
pub fn as_trait_method_without_default(&self) -> Option<()>
pub fn as_extern(&self) -> Option<&String>
pub fn as_intrinsic(&self) -> Option<(&String, &Vec<Option<String>>)>
pub fn as_opaque(&self) -> Option<()>
pub fn as_missing(&self) -> Option<()>
pub fn as_error(&self) -> Option<&Error>
Sourceimpl Body
impl Body
pub fn as_unstructured_mut(&mut self) -> Option<&mut ExprBody>
pub fn as_structured_mut(&mut self) -> Option<&mut ExprBody>
pub fn as_target_dispatch_mut( &mut self, ) -> Option<&mut SeqHashMap<TargetTriple, FunDeclRef>>
pub fn as_trait_method_without_default_mut(&mut self) -> Option<()>
pub fn as_extern_mut(&mut self) -> Option<&mut String>
pub fn as_intrinsic_mut( &mut self, ) -> Option<(&mut String, &mut Vec<Option<String>>)>
pub fn as_opaque_mut(&mut self) -> Option<()>
pub fn as_missing_mut(&mut self) -> Option<()>
pub fn as_error_mut(&mut self) -> Option<&mut Error>
Sourceimpl Body
impl Body
pub fn to_unstructured(self) -> Option<ExprBody>
pub fn to_structured(self) -> Option<ExprBody>
pub fn to_target_dispatch(self) -> Option<SeqHashMap<TargetTriple, FunDeclRef>>
pub fn to_trait_method_without_default(self) -> Option<()>
pub fn to_extern(self) -> Option<String>
pub fn to_intrinsic(self) -> Option<(String, Vec<Option<String>>)>
pub fn to_opaque(self) -> Option<()>
pub fn to_missing(self) -> Option<()>
pub fn to_error(self) -> Option<Error>