pub struct GExprBody<T> {
pub span: Span,
pub bound_body_regions: usize,
pub locals: Locals,
pub body: T,
pub comments: Vec<(usize, Vec<String>)>,
}Expand description
An expression body. TODO: arg_count should be stored in GFunDecl below. But then, the print is obfuscated and Aeneas may need some refactoring.
Fields
span: Spanbound_body_regions: usizeThe number of regions existentially bound in this body. We introduce fresh such regions during translation instead of the erased regions that rustc gives us.
locals: LocalsThe local variables.
body: TThe statements and blocks that compose this body.
comments: Vec<(usize, Vec<String>)>For each line inside the body, we record any whole-line // comments found before it. They
are added to statements in the late recover_body_comments pass.
Implementations
Sourceimpl GExprBody<IndexVec<BlockId, BlockData>>
impl GExprBody<IndexVec<BlockId, BlockData>>
Sourcepub fn as_abort_map(&self) -> HashMap<BlockId, AbortKind>
pub fn as_abort_map(&self) -> HashMap<BlockId, AbortKind>
Returns a map from blocks in this body to their abort kind, if they correspond to an abort block (ie. a block with no statements and an TerminatorKind::Abort terminator).
pub fn transform_sequences_fwd<F>(&mut self, f: F)
pub fn transform_sequences_bwd<F>(&mut self, f: F)
Sourcepub fn visit_statements<F: FnMut(&mut Statement)>(&mut self, f: F)
pub fn visit_statements<F: FnMut(&mut Statement)>(&mut self, f: F)
Apply a function to all the statements, in a bottom-up manner.
Sourceimpl<T> GExprBody<T>
impl<T> GExprBody<T>
fn fmt_with_ctx_and_callback<C: AstFormatter>( &self, ctx: &C, f: &mut Formatter<'_>, fmt_body: impl FnOnce(&mut Formatter<'_>, &<<C as AstFormatter>::Reborrow<'_> as AstFormatter>::Reborrow<'_>, &T) -> Result, ) -> Result